<template>
  <div class="app-container">
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mes:dv:checkplan:add']"
        >新增</el-button>
      </el-col>
    </el-row>
    <DvsubjectSelect ref="subjectSelect"  @onSelected="onSubjectSelected"></DvsubjectSelect>
    <el-table v-loading="loading" :data="checksubjectList" >
      <el-table-column label="项目编码" align="center" prop="itemsCode" />
      <el-table-column label="项目名称" align="center" prop="itemsName" />
      <el-table-column label="项目类型" align="center" prop="itemsType">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.spotmaintenance" :value="scope.row.itemsType"/>
        </template>
      </el-table-column>
      <el-table-column label="项目内容" align="center" width="300px" prop="itemsContent" />
      <el-table-column label="标准" align="center" width="300px" prop="standard" />
      <el-table-column label="操作" align="center" >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="danger"
            icon="el-icon-delete"
            @click="deleteSelectedColumns(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
  </div>
</template>

<script>
import { listInspectionPlanInfo, getInspectionPlanInfo, delInspectionPlanInfo, addInspectionPlanInfo, updateInspectionPlanInfo } from "@/api/main/em/inspectionPlanInfo/inspectionPlanInfo";
import DvsubjectSelect from "@/components/inspectionPlanItems/index.vue"
export default {
  name: "Checksubject",
  components:{DvsubjectSelect},
  dicts: ['spotmaintenance'],
  props:{
      id: null,
      optType: null
  },


  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
        selectedRows: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 点检项目表格数据
      checksubjectList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        planId: this.planId,
        itemsCode: null,
        itemsName: null,
        itemsType: null,
        standard: null,
        itemsContent: null,
      },
      // 表单参数
      form: {}
    };
  },
  created() {
    if(this.optType === 'add'){
      this.getList();
    }
    if(this.optType === 'edit'){
      this.getListedit();
    }
  },
  methods: {
    deleteSelectedColumns(row) {
      const index = this.checksubjectList.findIndex(item => item.id === row.id);
      if (index !== -1) {
        this.checksubjectList.splice(index, 1);
      } else {
        this.$message({
          message: '未找到具有该ID的项目',
          type: 'warning'
        });
      }
      this.$emit('subSelected',this.checksubjectList);

    },
    /** 查询点检项目列表 */
    getList() {
      this.loading = true;
      listInspectionPlanInfo(this.queryParams).then(response => {
        // this.checksubjectList = response.rows;
        this.total = response.total;
        this.loading = false;
        // console.log(response.rows)
      });
    },
    getListedit() {
      this.loading = true;
      this.queryParams.spareField1 = '项目清单'
      this.queryParams.spareField2 = this.id;
      listInspectionPlanInfo(this.queryParams).then(response => {
        this.checksubjectList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 新增按钮操作 */
    handleAdd() {
        this.$refs.subjectSelect.showFlag = true;
    },
    onSubjectSelected(selectedRows){
      if(selectedRows !=null && selectedRows.length >0){
        this.checksubjectList = selectedRows
      }
      this.$emit('subSelected',this.checksubjectList);
    },

  }
};
</script>
